---
title: MemGPT
sidebarTitle: MemGPT
---

![MemGPT Example](img/ecosystem-memgpt.png)

MemGPT enables LLMs to manage their own memory and overcome limited context windows. You can use MemGPT to create perpetual chatbots that learn about you and modify their own personalities over time. You can connect MemGPT to your own local filesystems and databases, as well as connect MemGPT to your own tools and APIs. The MemGPT + AG2 integration allows you to equip any AG2 agent with MemGPT capabilities.

- [MemGPT + AG2 Documentation with Code Examples](https://memgpt.readme.io/docs/autogen)
